==> wordpress_0.7.2.tar.gz: wordpress-0.7.2/src/apikeydialog.cpp <==
/*
 * apikeydialog.cpp
 *
 *  Created on: 15.3.2010
 *      Author: aahv
 */

#include <QPushButton>
#include <QMessageBox>
#include <QKeyEvent>

#include "apikeydialog.h"
#include "ui_apikeydialog.h"

ApiKeyDialog::ApiKeyDialog(QWidget *parent) :
        QDialog(parent),
        ui(new Ui::ApiKeyDialog)
{
#ifdef Q_WS_MAEMO_5
    setWindowFlags(Qt::Dialog);
#else
    setWindowFlags(Qt::Popup);
#endif

    ui->setupUi(this);

    ui->apiKeyText->SetExplanation(tr("API key"));

    setModal(true);
    
    iOkAction = new QAction(this);
    addAction(iOkAction);
    connect(iOkAction, SIGNAL(triggered()), this, SLOT(onOk()));
    connect(ui->okButton, SIGNAL(clicked()), iOkAction, SLOT(trigger()));
    
    iCancelAction = new QAction(this);
    addAction(iOkAction);
    connect(iCancelAction, SIGNAL(triggered()), this, SLOT(onCancel()));
    connect(ui->cancelButton, SIGNAL(clicked()), iCancelAction, SLOT(trigger()));    
}

ApiKeyDialog::~ApiKeyDialog()
{
    delete ui;
}

void ApiKeyDialog::changeEvent(QEvent *e)
{
    QDialog::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void ApiKeyDialog::onOk() {
    QString str = ui->apiKeyText->text().trimmed();
    if (str.length() == 12) {
        ui->apiKeyText->Clear();
        emit setApiKey(str);
        accept();
    } else {
        QMessageBox::warning(this, tr("Invalid API key"), tr("Invalid API key. It must be 12 characters long."), QMessageBox::Close, QMessageBox::Close);
    }
}

void ApiKeyDialog::onCancel() {
    ui->apiKeyText->Clear();
    reject();
}

void ApiKeyDialog::keyReleaseEvent ( QKeyEvent * event  )
{
    if (event->key() == Qt::Key_Context1 )
    {
        iOkAction->trigger();
        event->accept();
    }
    else if(event->key() == Qt::Key_Context2)
    {
        iCancelAction->trigger();
        event->accept();
    }
    else
    {
        event->ignore();
    }
}

void ApiKeyDialog::showEvent(QShowEvent * event)
    {
    QDialog::showEvent(event);
    ui->apiKeyText->setFocus();
    }

==> wordpress_0.7.3.tar.gz: wordpress-0.7.3/src/apikeydialog.cpp <==
/*
 * apikeydialog.cpp
 *
 *  Created on: 15.3.2010
 *      Author: aahv
 */

#include <QPushButton>
#include <QMessageBox>
#include <QKeyEvent>

#include "apikeydialog.h"
#include "ui_apikeydialog.h"

ApiKeyDialog::ApiKeyDialog(QWidget *parent) :
        QDialog(parent),
        ui(new Ui::ApiKeyDialog)
{
#ifdef Q_WS_MAEMO_5
    setWindowFlags(Qt::Dialog);
#else
    setWindowFlags(Qt::Popup);
#endif

    ui->setupUi(this);

    ui->apiKeyText->SetExplanation(tr("API key"));

    setModal(true);
    
    iOkAction = new QAction(this);
    addAction(iOkAction);
    connect(iOkAction, SIGNAL(triggered()), this, SLOT(onOk()));
    connect(ui->okButton, SIGNAL(clicked()), iOkAction, SLOT(trigger()));
    
    iCancelAction = new QAction(this);
    addAction(iOkAction);
    connect(iCancelAction, SIGNAL(triggered()), this, SLOT(onCancel()));
    connect(ui->cancelButton, SIGNAL(clicked()), iCancelAction, SLOT(trigger()));    
}

ApiKeyDialog::~ApiKeyDialog()
{
    delete ui;
}

void ApiKeyDialog::changeEvent(QEvent *e)
{
    QDialog::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void ApiKeyDialog::onOk() {
    QString str = ui->apiKeyText->text().trimmed();
    if (str.length() == 12) {
        ui->apiKeyText->Clear();
        emit setApiKey(str);
        accept();
    } else {
        QMessageBox::warning(this, tr("Invalid API key"), tr("Invalid API key. It must be 12 characters long."), QMessageBox::Close, QMessageBox::Close);
    }
}

void ApiKeyDialog::onCancel() {
    ui->apiKeyText->Clear();
    reject();
}

void ApiKeyDialog::keyPressEvent ( QKeyEvent * event  )
{
    if (event->key() == Qt::Key_Context1 )
    {
        iOkAction->trigger();
        event->accept();
    }
    else if(event->key() == Qt::Key_Context2)
    {
        iCancelAction->trigger();
        event->accept();
    }
    else
    {
        QDialog::keyPressEvent(event);
    }
}

void ApiKeyDialog::showEvent(QShowEvent * event)
    {
    QDialog::showEvent(event);
    ui->apiKeyText->setFocus();
    }
